#[non_exhaustive]pub struct CreateNetworkMigrationDefinitionInput {
pub name: Option<String>,
pub description: Option<String>,
pub source_configurations: Option<Vec<SourceConfiguration>>,
pub target_s3_configuration: Option<TargetS3Configuration>,
pub target_network: Option<TargetNetwork>,
pub target_deployment: Option<TargetDeployment>,
pub tags: Option<HashMap<String, String>>,
pub scope_tags: Option<HashMap<String, String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: Option<String>The name of the network migration definition.
description: Option<String>A description of the network migration definition.
source_configurations: Option<Vec<SourceConfiguration>>A list of source configurations for the network migration.
target_s3_configuration: Option<TargetS3Configuration>The S3 configuration for storing the target network artifacts.
target_network: Option<TargetNetwork>The target network configuration including topology and CIDR ranges.
target_deployment: Option<TargetDeployment>The target deployment configuration for the migrated network.
Tags to assign to the network migration definition.
Scope tags for the network migration definition to control access and organization.
Implementations
Sourceimpl CreateNetworkMigrationDefinitionInput
impl CreateNetworkMigrationDefinitionInput
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
A description of the network migration definition.
Sourcepub fn source_configurations(&self) -> &[SourceConfiguration]
pub fn source_configurations(&self) -> &[SourceConfiguration]
A list of source configurations for the network migration.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .source_configurations.is_none().
Sourcepub fn target_s3_configuration(&self) -> Option<&TargetS3Configuration>
pub fn target_s3_configuration(&self) -> Option<&TargetS3Configuration>
The S3 configuration for storing the target network artifacts.
Sourcepub fn target_network(&self) -> Option<&TargetNetwork>
pub fn target_network(&self) -> Option<&TargetNetwork>
The target network configuration including topology and CIDR ranges.
Sourcepub fn target_deployment(&self) -> Option<&TargetDeployment>
pub fn target_deployment(&self) -> Option<&TargetDeployment>
The target deployment configuration for the migrated network.
Tags to assign to the network migration definition.
Scope tags for the network migration definition to control access and organization.
Sourceimpl CreateNetworkMigrationDefinitionInput
impl CreateNetworkMigrationDefinitionInput
Sourcepub fn builder() -> CreateNetworkMigrationDefinitionInputBuilder
pub fn builder() -> CreateNetworkMigrationDefinitionInputBuilder
Creates a new builder-style object to manufacture CreateNetworkMigrationDefinitionInput.