#[non_exhaustive]pub struct CreateNetworkMigrationDefinitionOutput {
pub arn: Option<String>,
pub network_migration_definition_id: Option<String>,
pub name: Option<String>,
pub description: Option<String>,
pub source_configurations: Option<Vec<SourceConfiguration>>,
pub target_s3_configuration: Option<TargetS3Configuration>,
pub target_network: Option<TargetNetwork>,
pub target_deployment: Option<TargetDeployment>,
pub created_at: Option<DateTime>,
pub updated_at: Option<DateTime>,
pub tags: Option<HashMap<String, String>>,
pub scope_tags: Option<HashMap<String, String>>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.arn: Option<String>The Amazon Resource Name (ARN) of the network migration definition.
network_migration_definition_id: Option<String>The unique identifier of the network migration definition.
name: Option<String>The name of the network migration definition.
description: Option<String>A description of the network migration definition.
source_configurations: Option<Vec<SourceConfiguration>>A list of source configurations for the network migration.
target_s3_configuration: Option<TargetS3Configuration>The S3 configuration for storing the target network artifacts.
target_network: Option<TargetNetwork>The target network configuration including topology and CIDR ranges.
target_deployment: Option<TargetDeployment>The target deployment configuration for the migrated network.
created_at: Option<DateTime>The timestamp when the network migration definition was created.
updated_at: Option<DateTime>The timestamp when the network migration definition was last updated.
Tags assigned to the network migration definition.
Scope tags for the network migration definition.
Implementations
Sourceimpl CreateNetworkMigrationDefinitionOutput
impl CreateNetworkMigrationDefinitionOutput
Sourcepub fn arn(&self) -> Option<&str>
pub fn arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the network migration definition.
Sourcepub fn network_migration_definition_id(&self) -> Option<&str>
pub fn network_migration_definition_id(&self) -> Option<&str>
The unique identifier of the network migration definition.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
A description of the network migration definition.
Sourcepub fn source_configurations(&self) -> &[SourceConfiguration]
pub fn source_configurations(&self) -> &[SourceConfiguration]
A list of source configurations for the network migration.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .source_configurations.is_none().
Sourcepub fn target_s3_configuration(&self) -> Option<&TargetS3Configuration>
pub fn target_s3_configuration(&self) -> Option<&TargetS3Configuration>
The S3 configuration for storing the target network artifacts.
Sourcepub fn target_network(&self) -> Option<&TargetNetwork>
pub fn target_network(&self) -> Option<&TargetNetwork>
The target network configuration including topology and CIDR ranges.
Sourcepub fn target_deployment(&self) -> Option<&TargetDeployment>
pub fn target_deployment(&self) -> Option<&TargetDeployment>
The target deployment configuration for the migrated network.
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
The timestamp when the network migration definition was created.
Sourcepub fn updated_at(&self) -> Option<&DateTime>
pub fn updated_at(&self) -> Option<&DateTime>
The timestamp when the network migration definition was last updated.
Tags assigned to the network migration definition.
Scope tags for the network migration definition.
Sourceimpl CreateNetworkMigrationDefinitionOutput
impl CreateNetworkMigrationDefinitionOutput
Sourcepub fn builder() -> CreateNetworkMigrationDefinitionOutputBuilder
pub fn builder() -> CreateNetworkMigrationDefinitionOutputBuilder
Creates a new builder-style object to manufacture CreateNetworkMigrationDefinitionOutput.