#[non_exhaustive]pub enum StartNetworkMigrationMappingError {
AccessDeniedException(AccessDeniedException),
ConflictException(ConflictException),
ResourceNotFoundException(ResourceNotFoundException),
ServiceQuotaExceededException(ServiceQuotaExceededException),
ThrottlingException(ThrottlingException),
ValidationException(ValidationException),
Unhandled(Unhandled),
}Expand description
Error type for the StartNetworkMigrationMappingError operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AccessDeniedException(AccessDeniedException)
Operating denied due to a file permission or access check error.
ConflictException(ConflictException)
The request could not be completed due to a conflict with the current state of the target resource.
ResourceNotFoundException(ResourceNotFoundException)
Resource not found exception.
ServiceQuotaExceededException(ServiceQuotaExceededException)
The request could not be completed because its exceeded the service quota.
ThrottlingException(ThrottlingException)
Reached throttling quota exception.
ValidationException(ValidationException)
Validate exception.
Unhandled(Unhandled)
Matching Unhandled directly is not forwards compatible. Instead, match using a variable wildcard pattern and check .code():
err if err.code() == Some("SpecificExceptionCode") => { /* handle the error */ }
See ProvideErrorMetadata for what information is available for the error.
An unexpected error occurred (e.g., invalid JSON returned by the service or an unknown error code).
Implementations
Sourceimpl StartNetworkMigrationMappingError
impl StartNetworkMigrationMappingError
Sourcepub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
pub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
Creates the StartNetworkMigrationMappingError::Unhandled variant from any error type.
Sourcepub fn generic(err: ErrorMetadata) -> Self
pub fn generic(err: ErrorMetadata) -> Self
Creates the StartNetworkMigrationMappingError::Unhandled variant from an ErrorMetadata.
Sourcepub fn meta(&self) -> &ErrorMetadata
pub fn meta(&self) -> &ErrorMetadata
Returns error metadata, which includes the error code, message, request ID, and potentially additional information.
Sourcepub fn is_access_denied_exception(&self) -> bool
pub fn is_access_denied_exception(&self) -> bool
Returns true if the error kind is StartNetworkMigrationMappingError::AccessDeniedException.
Sourcepub fn is_conflict_exception(&self) -> bool
pub fn is_conflict_exception(&self) -> bool
Returns true if the error kind is StartNetworkMigrationMappingError::ConflictException.
Sourcepub fn is_resource_not_found_exception(&self) -> bool
pub fn is_resource_not_found_exception(&self) -> bool
Returns true if the error kind is StartNetworkMigrationMappingError::ResourceNotFoundException.
Sourcepub fn is_service_quota_exceeded_exception(&self) -> bool
pub fn is_service_quota_exceeded_exception(&self) -> bool
Returns true if the error kind is StartNetworkMigrationMappingError::ServiceQuotaExceededException.
Sourcepub fn is_throttling_exception(&self) -> bool
pub fn is_throttling_exception(&self) -> bool
Returns true if the error kind is StartNetworkMigrationMappingError::ThrottlingException.
Sourcepub fn is_validation_exception(&self) -> bool
pub fn is_validation_exception(&self) -> bool
Returns true if the error kind is StartNetworkMigrationMappingError::ValidationException.