#[non_exhaustive]pub struct UpdateNetworkMigrationMapperSegmentOutput {Show 15 fields
pub job_id: Option<String>,
pub network_migration_execution_id: Option<String>,
pub network_migration_definition_id: Option<String>,
pub segment_id: Option<String>,
pub segment_type: Option<NetworkMigrationMapperSegmentType>,
pub name: Option<String>,
pub description: Option<String>,
pub logical_id: Option<String>,
pub checksum: Option<Checksum>,
pub output_s3_configuration: Option<S3Configuration>,
pub created_at: Option<DateTime>,
pub updated_at: Option<DateTime>,
pub scope_tags: Option<HashMap<String, String>>,
pub target_account: Option<String>,
pub referenced_segments: Option<Vec<String>>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.job_id: Option<String>The unique identifier of the job that created this segment.
network_migration_execution_id: Option<String>The unique identifier of the network migration execution.
network_migration_definition_id: Option<String>The unique identifier of the network migration definition.
segment_id: Option<String>The unique identifier of the segment.
segment_type: Option<NetworkMigrationMapperSegmentType>The type of the segment, such as VPC, subnet, or security group.
name: Option<String>The name of the segment.
description: Option<String>A description of the segment.
logical_id: Option<String>The logical identifier for the segment in the infrastructure code.
checksum: Option<Checksum>The checksum of the segment data for integrity verification.
output_s3_configuration: Option<S3Configuration>The S3 location where segment artifacts are stored.
created_at: Option<DateTime>The timestamp when the segment was created.
updated_at: Option<DateTime>The timestamp when the segment was last updated.
Scope tags for the segment.
target_account: Option<String>The target AWS account where this segment will be deployed.
referenced_segments: Option<Vec<String>>A list of other segments that this segment depends on or references.
Implementations
Sourceimpl UpdateNetworkMigrationMapperSegmentOutput
impl UpdateNetworkMigrationMapperSegmentOutput
Sourcepub fn job_id(&self) -> Option<&str>
pub fn job_id(&self) -> Option<&str>
The unique identifier of the job that created this segment.
Sourcepub fn network_migration_execution_id(&self) -> Option<&str>
pub fn network_migration_execution_id(&self) -> Option<&str>
The unique identifier of the network migration execution.
Sourcepub fn network_migration_definition_id(&self) -> Option<&str>
pub fn network_migration_definition_id(&self) -> Option<&str>
The unique identifier of the network migration definition.
Sourcepub fn segment_id(&self) -> Option<&str>
pub fn segment_id(&self) -> Option<&str>
The unique identifier of the segment.
Sourcepub fn segment_type(&self) -> Option<&NetworkMigrationMapperSegmentType>
pub fn segment_type(&self) -> Option<&NetworkMigrationMapperSegmentType>
The type of the segment, such as VPC, subnet, or security group.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
A description of the segment.
Sourcepub fn logical_id(&self) -> Option<&str>
pub fn logical_id(&self) -> Option<&str>
The logical identifier for the segment in the infrastructure code.
Sourcepub fn checksum(&self) -> Option<&Checksum>
pub fn checksum(&self) -> Option<&Checksum>
The checksum of the segment data for integrity verification.
Sourcepub fn output_s3_configuration(&self) -> Option<&S3Configuration>
pub fn output_s3_configuration(&self) -> Option<&S3Configuration>
The S3 location where segment artifacts are stored.
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
The timestamp when the segment was created.
Sourcepub fn updated_at(&self) -> Option<&DateTime>
pub fn updated_at(&self) -> Option<&DateTime>
The timestamp when the segment was last updated.
Scope tags for the segment.
Sourcepub fn target_account(&self) -> Option<&str>
pub fn target_account(&self) -> Option<&str>
The target AWS account where this segment will be deployed.
Sourcepub fn referenced_segments(&self) -> &[String]
pub fn referenced_segments(&self) -> &[String]
A list of other segments that this segment depends on or references.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .referenced_segments.is_none().
Sourceimpl UpdateNetworkMigrationMapperSegmentOutput
impl UpdateNetworkMigrationMapperSegmentOutput
Sourcepub fn builder() -> UpdateNetworkMigrationMapperSegmentOutputBuilder
pub fn builder() -> UpdateNetworkMigrationMapperSegmentOutputBuilder
Creates a new builder-style object to manufacture UpdateNetworkMigrationMapperSegmentOutput.