#[non_exhaustive]pub struct ImportFileEnrichment {
pub job_id: Option<String>,
pub created_at: Option<DateTime>,
pub ended_at: Option<DateTime>,
pub status: Option<ImportFileEnrichmentStatus>,
pub status_details: Option<String>,
pub checksum: Option<Checksum>,
pub s3_bucket_target: Option<EnrichmentTargetS3Configuration>,
}Expand description
Details about an import file enrichment job.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.job_id: Option<String>The unique identifier of the import file enrichment job.
created_at: Option<DateTime>The timestamp when the enrichment job was created.
ended_at: Option<DateTime>The timestamp when the enrichment job completed or failed.
status: Option<ImportFileEnrichmentStatus>The current status of the import file enrichment job.
status_details: Option<String>Detailed status information about the enrichment job.
checksum: Option<Checksum>The checksum of the enriched file for integrity verification.
s3_bucket_target: Option<EnrichmentTargetS3Configuration>The target S3 configuration for the enriched import file.
Implementations
Sourceimpl ImportFileEnrichment
impl ImportFileEnrichment
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
The timestamp when the enrichment job was created.
Sourcepub fn ended_at(&self) -> Option<&DateTime>
pub fn ended_at(&self) -> Option<&DateTime>
The timestamp when the enrichment job completed or failed.
Sourcepub fn status(&self) -> Option<&ImportFileEnrichmentStatus>
pub fn status(&self) -> Option<&ImportFileEnrichmentStatus>
The current status of the import file enrichment job.
Sourcepub fn status_details(&self) -> Option<&str>
pub fn status_details(&self) -> Option<&str>
Detailed status information about the enrichment job.
Sourcepub fn checksum(&self) -> Option<&Checksum>
pub fn checksum(&self) -> Option<&Checksum>
The checksum of the enriched file for integrity verification.
Sourcepub fn s3_bucket_target(&self) -> Option<&EnrichmentTargetS3Configuration>
pub fn s3_bucket_target(&self) -> Option<&EnrichmentTargetS3Configuration>
The target S3 configuration for the enriched import file.
Sourceimpl ImportFileEnrichment
impl ImportFileEnrichment
Sourcepub fn builder() -> ImportFileEnrichmentBuilder
pub fn builder() -> ImportFileEnrichmentBuilder
Creates a new builder-style object to manufacture ImportFileEnrichment.