#[non_exhaustive]pub struct NetworkMigrationAnalysisResult {
pub job_id: Option<String>,
pub network_migration_execution_id: Option<String>,
pub network_migration_definition_id: Option<String>,
pub analyzer_type: Option<AnalyzerType>,
pub source: Option<NetworkMigrationAnalysisResultSource>,
pub target: Option<NetworkMigrationAnalysisResultTarget>,
pub status: Option<NetworkMigrationAnalysisResultStatus>,
pub analysis_result: Option<String>,
}Expand description
The result of a network migration analysis operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.job_id: Option<String>The unique identifier of the analysis job that generated this result.
network_migration_execution_id: Option<String>The unique identifier of the network migration execution.
network_migration_definition_id: Option<String>The unique identifier of the network migration definition.
analyzer_type: Option<AnalyzerType>The type of analyzer that generated this result.
source: Option<NetworkMigrationAnalysisResultSource>The source resource that was analyzed.
target: Option<NetworkMigrationAnalysisResultTarget>The target resource in the analysis.
status: Option<NetworkMigrationAnalysisResultStatus>The status of the analysis result.
analysis_result: Option<String>The detailed analysis findings and recommendations.
Implementations
Sourceimpl NetworkMigrationAnalysisResult
impl NetworkMigrationAnalysisResult
Sourcepub fn job_id(&self) -> Option<&str>
pub fn job_id(&self) -> Option<&str>
The unique identifier of the analysis job that generated this result.
Sourcepub fn network_migration_execution_id(&self) -> Option<&str>
pub fn network_migration_execution_id(&self) -> Option<&str>
The unique identifier of the network migration execution.
Sourcepub fn network_migration_definition_id(&self) -> Option<&str>
pub fn network_migration_definition_id(&self) -> Option<&str>
The unique identifier of the network migration definition.
Sourcepub fn analyzer_type(&self) -> Option<&AnalyzerType>
pub fn analyzer_type(&self) -> Option<&AnalyzerType>
The type of analyzer that generated this result.
Sourcepub fn source(&self) -> Option<&NetworkMigrationAnalysisResultSource>
pub fn source(&self) -> Option<&NetworkMigrationAnalysisResultSource>
The source resource that was analyzed.
Sourcepub fn target(&self) -> Option<&NetworkMigrationAnalysisResultTarget>
pub fn target(&self) -> Option<&NetworkMigrationAnalysisResultTarget>
The target resource in the analysis.
Sourcepub fn status(&self) -> Option<&NetworkMigrationAnalysisResultStatus>
pub fn status(&self) -> Option<&NetworkMigrationAnalysisResultStatus>
The status of the analysis result.
Sourcepub fn analysis_result(&self) -> Option<&str>
pub fn analysis_result(&self) -> Option<&str>
The detailed analysis findings and recommendations.
Sourceimpl NetworkMigrationAnalysisResult
impl NetworkMigrationAnalysisResult
Sourcepub fn builder() -> NetworkMigrationAnalysisResultBuilder
pub fn builder() -> NetworkMigrationAnalysisResultBuilder
Creates a new builder-style object to manufacture NetworkMigrationAnalysisResult.