#[non_exhaustive]pub struct NetworkMigrationCodeGenerationJobDetails {
pub job_id: Option<String>,
pub network_migration_execution_id: Option<String>,
pub network_migration_definition_id: Option<String>,
pub created_at: Option<DateTime>,
pub ended_at: Option<DateTime>,
pub status: Option<NetworkMigrationJobStatus>,
pub status_details: Option<String>,
pub code_generation_output_format_status_details_map: Option<HashMap<CodeGenerationOutputFormatType, CodeGenerationOutputFormatStatusDetails>>,
}Expand description
Details about a network migration code generation job.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.job_id: Option<String>The unique identifier of the code generation job.
network_migration_execution_id: Option<String>The unique identifier of the network migration execution.
network_migration_definition_id: Option<String>The unique identifier of the network migration definition.
created_at: Option<DateTime>The timestamp when the job was created.
ended_at: Option<DateTime>The timestamp when the job completed or failed.
status: Option<NetworkMigrationJobStatus>The current status of the code generation job.
status_details: Option<String>Detailed status information about the job.
code_generation_output_format_status_details_map: Option<HashMap<CodeGenerationOutputFormatType, CodeGenerationOutputFormatStatusDetails>>A map of output format types to their status details.
Implementations
Sourceimpl NetworkMigrationCodeGenerationJobDetails
impl NetworkMigrationCodeGenerationJobDetails
Sourcepub fn network_migration_execution_id(&self) -> Option<&str>
pub fn network_migration_execution_id(&self) -> Option<&str>
The unique identifier of the network migration execution.
Sourcepub fn network_migration_definition_id(&self) -> Option<&str>
pub fn network_migration_definition_id(&self) -> Option<&str>
The unique identifier of the network migration definition.
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
The timestamp when the job was created.
Sourcepub fn status(&self) -> Option<&NetworkMigrationJobStatus>
pub fn status(&self) -> Option<&NetworkMigrationJobStatus>
The current status of the code generation job.
Sourcepub fn status_details(&self) -> Option<&str>
pub fn status_details(&self) -> Option<&str>
Detailed status information about the job.
Sourcepub fn code_generation_output_format_status_details_map(
&self,
) -> Option<&HashMap<CodeGenerationOutputFormatType, CodeGenerationOutputFormatStatusDetails>>
pub fn code_generation_output_format_status_details_map( &self, ) -> Option<&HashMap<CodeGenerationOutputFormatType, CodeGenerationOutputFormatStatusDetails>>
A map of output format types to their status details.
Sourceimpl NetworkMigrationCodeGenerationJobDetails
impl NetworkMigrationCodeGenerationJobDetails
Sourcepub fn builder() -> NetworkMigrationCodeGenerationJobDetailsBuilder
pub fn builder() -> NetworkMigrationCodeGenerationJobDetailsBuilder
Creates a new builder-style object to manufacture NetworkMigrationCodeGenerationJobDetails.