#[non_exhaustive]pub struct NetworkMigrationCodeGenerationSegment {
pub job_id: Option<String>,
pub network_migration_execution_id: Option<String>,
pub network_migration_definition_id: Option<String>,
pub segment_id: Option<String>,
pub segment_type: Option<NetworkMigrationCodeGenerationSegmentType>,
pub logical_id: Option<String>,
pub mapper_segment_id: Option<String>,
pub artifacts: Option<Vec<NetworkMigrationCodeGenerationArtifact>>,
pub created_at: Option<DateTime>,
}Expand description
A segment of generated code representing a logical grouping of infrastructure resources.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.job_id: Option<String>The unique identifier of the code generation job.
network_migration_execution_id: Option<String>The unique identifier of the network migration execution.
network_migration_definition_id: Option<String>The unique identifier of the network migration definition.
segment_id: Option<String>The unique identifier of the segment.
segment_type: Option<NetworkMigrationCodeGenerationSegmentType>The type of the segment.
logical_id: Option<String>The logical identifier for the segment.
mapper_segment_id: Option<String>The ID of the mapper segment that this code generation segment was created from.
artifacts: Option<Vec<NetworkMigrationCodeGenerationArtifact>>A list of artifacts generated for this segment.
created_at: Option<DateTime>The timestamp when the segment was created.
Implementations
Sourceimpl NetworkMigrationCodeGenerationSegment
impl NetworkMigrationCodeGenerationSegment
Sourcepub fn network_migration_execution_id(&self) -> Option<&str>
pub fn network_migration_execution_id(&self) -> Option<&str>
The unique identifier of the network migration execution.
Sourcepub fn network_migration_definition_id(&self) -> Option<&str>
pub fn network_migration_definition_id(&self) -> Option<&str>
The unique identifier of the network migration definition.
Sourcepub fn segment_id(&self) -> Option<&str>
pub fn segment_id(&self) -> Option<&str>
The unique identifier of the segment.
Sourcepub fn segment_type(&self) -> Option<&NetworkMigrationCodeGenerationSegmentType>
pub fn segment_type(&self) -> Option<&NetworkMigrationCodeGenerationSegmentType>
The type of the segment.
Sourcepub fn logical_id(&self) -> Option<&str>
pub fn logical_id(&self) -> Option<&str>
The logical identifier for the segment.
Sourcepub fn mapper_segment_id(&self) -> Option<&str>
pub fn mapper_segment_id(&self) -> Option<&str>
The ID of the mapper segment that this code generation segment was created from.
Sourcepub fn artifacts(&self) -> &[NetworkMigrationCodeGenerationArtifact]
pub fn artifacts(&self) -> &[NetworkMigrationCodeGenerationArtifact]
A list of artifacts generated for this segment.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .artifacts.is_none().
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
The timestamp when the segment was created.
Sourceimpl NetworkMigrationCodeGenerationSegment
impl NetworkMigrationCodeGenerationSegment
Sourcepub fn builder() -> NetworkMigrationCodeGenerationSegmentBuilder
pub fn builder() -> NetworkMigrationCodeGenerationSegmentBuilder
Creates a new builder-style object to manufacture NetworkMigrationCodeGenerationSegment.