#[non_exhaustive]pub struct NetworkMigrationDeployedStackDetails {
pub status: Option<NetworkMigrationDeployedStackStatus>,
pub stack_physical_id: Option<String>,
pub stack_logical_id: Option<String>,
pub segment_id: Option<String>,
pub target_account: Option<String>,
pub failed_resources: Option<Vec<NetworkMigrationFailedResourceDetails>>,
}Expand description
Details about a CloudFormation stack that has been deployed as part of the network migration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.status: Option<NetworkMigrationDeployedStackStatus>The current status of the deployed stack.
stack_physical_id: Option<String>The physical ID of the CloudFormation stack.
stack_logical_id: Option<String>The logical ID of the stack.
segment_id: Option<String>The ID of the segment that this stack was deployed for.
target_account: Option<String>The target AWS account where the stack was deployed.
failed_resources: Option<Vec<NetworkMigrationFailedResourceDetails>>A list of resources that failed to deploy.
Implementations
Sourceimpl NetworkMigrationDeployedStackDetails
impl NetworkMigrationDeployedStackDetails
Sourcepub fn status(&self) -> Option<&NetworkMigrationDeployedStackStatus>
pub fn status(&self) -> Option<&NetworkMigrationDeployedStackStatus>
The current status of the deployed stack.
Sourcepub fn stack_physical_id(&self) -> Option<&str>
pub fn stack_physical_id(&self) -> Option<&str>
The physical ID of the CloudFormation stack.
Sourcepub fn stack_logical_id(&self) -> Option<&str>
pub fn stack_logical_id(&self) -> Option<&str>
The logical ID of the stack.
Sourcepub fn segment_id(&self) -> Option<&str>
pub fn segment_id(&self) -> Option<&str>
The ID of the segment that this stack was deployed for.
Sourcepub fn target_account(&self) -> Option<&str>
pub fn target_account(&self) -> Option<&str>
The target AWS account where the stack was deployed.
Sourcepub fn failed_resources(&self) -> &[NetworkMigrationFailedResourceDetails]
pub fn failed_resources(&self) -> &[NetworkMigrationFailedResourceDetails]
A list of resources that failed to deploy.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .failed_resources.is_none().
Sourceimpl NetworkMigrationDeployedStackDetails
impl NetworkMigrationDeployedStackDetails
Sourcepub fn builder() -> NetworkMigrationDeployedStackDetailsBuilder
pub fn builder() -> NetworkMigrationDeployedStackDetailsBuilder
Creates a new builder-style object to manufacture NetworkMigrationDeployedStackDetails.