#[non_exhaustive]pub struct NetworkMigrationExecution {
pub network_migration_definition_id: Option<String>,
pub network_migration_execution_id: Option<String>,
pub status: Option<ExecutionStatus>,
pub stage: Option<ExecutionStage>,
pub activity: Option<ExecutionStageActivity>,
pub created_at: Option<DateTime>,
pub updated_at: Option<DateTime>,
pub tags: Option<HashMap<String, String>>,
}Expand description
Details about a network migration execution instance.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.network_migration_definition_id: Option<String>The unique identifier of the network migration definition used by this execution.
network_migration_execution_id: Option<String>The unique identifier of the execution.
status: Option<ExecutionStatus>The current status of the execution.
stage: Option<ExecutionStage>The current stage of the execution in the migration workflow.
activity: Option<ExecutionStageActivity>The current activity being performed in the execution.
created_at: Option<DateTime>The timestamp when the execution was created.
updated_at: Option<DateTime>The timestamp when the execution was last updated.
Tags assigned to the execution.
Implementations
Sourceimpl NetworkMigrationExecution
impl NetworkMigrationExecution
Sourcepub fn network_migration_definition_id(&self) -> Option<&str>
pub fn network_migration_definition_id(&self) -> Option<&str>
The unique identifier of the network migration definition used by this execution.
Sourcepub fn network_migration_execution_id(&self) -> Option<&str>
pub fn network_migration_execution_id(&self) -> Option<&str>
The unique identifier of the execution.
Sourcepub fn status(&self) -> Option<&ExecutionStatus>
pub fn status(&self) -> Option<&ExecutionStatus>
The current status of the execution.
Sourcepub fn stage(&self) -> Option<&ExecutionStage>
pub fn stage(&self) -> Option<&ExecutionStage>
The current stage of the execution in the migration workflow.
Sourcepub fn activity(&self) -> Option<&ExecutionStageActivity>
pub fn activity(&self) -> Option<&ExecutionStageActivity>
The current activity being performed in the execution.
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
The timestamp when the execution was created.
Sourcepub fn updated_at(&self) -> Option<&DateTime>
pub fn updated_at(&self) -> Option<&DateTime>
The timestamp when the execution was last updated.
Tags assigned to the execution.
Sourceimpl NetworkMigrationExecution
impl NetworkMigrationExecution
Sourcepub fn builder() -> NetworkMigrationExecutionBuilder
pub fn builder() -> NetworkMigrationExecutionBuilder
Creates a new builder-style object to manufacture NetworkMigrationExecution.