#[non_exhaustive]pub struct NetworkMigrationMapperSegmentConstruct {
pub construct_id: Option<String>,
pub construct_type: Option<String>,
pub name: Option<String>,
pub description: Option<String>,
pub logical_id: Option<String>,
pub excluded: Option<bool>,
pub created_at: Option<DateTime>,
pub updated_at: Option<DateTime>,
pub properties: Option<HashMap<String, String>>,
}Expand description
Represents a construct within a mapper segment. A construct is an individual infrastructure component such as a VPC, subnet, security group, route table, or other network resource that is part of the network migration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.construct_id: Option<String>The unique identifier of the construct.
construct_type: Option<String>The type of the construct, such as VPC, subnet, security group, or route table.
name: Option<String>The name of the construct.
description: Option<String>A description of the construct.
logical_id: Option<String>The logical identifier for the construct in the infrastructure code.
excluded: Option<bool>Whether this construct is excluded from the migration.
created_at: Option<DateTime>The timestamp when the construct was created.
updated_at: Option<DateTime>The timestamp when the construct was last updated.
properties: Option<HashMap<String, String>>The properties and configuration of the construct.
Implementations
Sourceimpl NetworkMigrationMapperSegmentConstruct
impl NetworkMigrationMapperSegmentConstruct
Sourcepub fn construct_id(&self) -> Option<&str>
pub fn construct_id(&self) -> Option<&str>
The unique identifier of the construct.
Sourcepub fn construct_type(&self) -> Option<&str>
pub fn construct_type(&self) -> Option<&str>
The type of the construct, such as VPC, subnet, security group, or route table.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
A description of the construct.
Sourcepub fn logical_id(&self) -> Option<&str>
pub fn logical_id(&self) -> Option<&str>
The logical identifier for the construct in the infrastructure code.
Sourcepub fn created_at(&self) -> Option<&DateTime>
pub fn created_at(&self) -> Option<&DateTime>
The timestamp when the construct was created.
Sourcepub fn updated_at(&self) -> Option<&DateTime>
pub fn updated_at(&self) -> Option<&DateTime>
The timestamp when the construct was last updated.
Sourceimpl NetworkMigrationMapperSegmentConstruct
impl NetworkMigrationMapperSegmentConstruct
Sourcepub fn builder() -> NetworkMigrationMapperSegmentConstructBuilder
pub fn builder() -> NetworkMigrationMapperSegmentConstructBuilder
Creates a new builder-style object to manufacture NetworkMigrationMapperSegmentConstruct.