#[non_exhaustive]pub struct TargetNetwork {
pub topology: TargetNetworkTopology,
pub inbound_cidr: Option<String>,
pub outbound_cidr: Option<String>,
pub inspection_cidr: Option<String>,
}Expand description
Configuration for the target network topology and addressing.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.topology: TargetNetworkTopologyThe network topology type for the target environment.
inbound_cidr: Option<String>The CIDR block for inbound traffic in the target network.
outbound_cidr: Option<String>The CIDR block for outbound traffic in the target network.
inspection_cidr: Option<String>The CIDR block for inspection traffic in the target network.
Implementations
Sourceimpl TargetNetwork
impl TargetNetwork
Sourcepub fn topology(&self) -> &TargetNetworkTopology
pub fn topology(&self) -> &TargetNetworkTopology
The network topology type for the target environment.
Sourcepub fn inbound_cidr(&self) -> Option<&str>
pub fn inbound_cidr(&self) -> Option<&str>
The CIDR block for inbound traffic in the target network.
Sourcepub fn outbound_cidr(&self) -> Option<&str>
pub fn outbound_cidr(&self) -> Option<&str>
The CIDR block for outbound traffic in the target network.
Sourcepub fn inspection_cidr(&self) -> Option<&str>
pub fn inspection_cidr(&self) -> Option<&str>
The CIDR block for inspection traffic in the target network.
Sourceimpl TargetNetwork
impl TargetNetwork
Sourcepub fn builder() -> TargetNetworkBuilder
pub fn builder() -> TargetNetworkBuilder
Creates a new builder-style object to manufacture TargetNetwork.